# py-pdf-parser

[![PyPI version](https://badge.fury.io/py/py-pdf-parser.svg)](https://badge.fury.io/py/py-pdf-parser)
![Continuous Integration](https://github.com/jstockwin/py-pdf-parser/workflows/Continuous%20Integration/badge.svg)
[![Documentation Status](https://readthedocs.org/projects/py-pdf-parser/badge/?version=latest)](https://py-pdf-parser.readthedocs.io/en/latest/?badge=latest)

Py PDF Parser is a tool to help extracting information from structured PDFs.

Full details and installation instructions can be found at:
https://py-pdf-parser.readthedocs.io/en/latest/

This project is based on an original design and protoype by Sam Whitehall (github.com/samwhitehall).
